@@ -25,10 +25,10 @@ def send_notifications():
     for notify in notifies.iterator():
         if notify.state == STATE.WAIT:
             if notify.send_at is None:
-                notify._start_send()
+                notify.start_send()
             else:
                 if timezone.now() > notify.send_at:
-                    notify._start_send()
+                    notify.start_send()
     return
 
 
